<?php
require dirname(dirname(__FILE__)) . '/inc/Connection.php';

class Prozigzig
{
    private $probus;

    public function __construct()
    {
        // Establish database connection
        $this->probus = new mysqli(DB_HOST, DB_USER, DB_PASS, DB_NAME);

        if ($this->probus->connect_error) {
            die("Connection failed: " . $this->probus->connect_error);
        }

        // Set UTF-8 character encoding
        if (!$this->probus->set_charset("utf8mb4")) {
            echo "Warning: Error loading character set utf8mb4: " . $this->probus->error;
        }
    }

    // Method to safely escape strings for database queries
    public function real_string($string)
    {
        return $this->probus->real_escape_string($string);
    }

    // ✅ Method to Fetch a Single Row
    public function fetchData($query)
    {
        $result = $this->probus->query($query);
        if ($result) {
            return $result->fetch_assoc(); // Return first row as an associative array
        } else {
            return []; // Return empty array if query fails
        }
    }

    // ✅ Method to Fetch Multiple Rows (Added as fetchDataQuery)
    public function fetchDataQuery($query)
    {
        $result = $this->probus->query($query);
        $data = [];
        if ($result) {
            while ($row = $result->fetch_assoc()) {
                $data[] = $row;
            }
        }
        return $data; // Return all rows as an array
    }

    // User login authentication
    public function login(string $username, string $password, string $tblname): int
    {
        $query = ($tblname == "admin") ?
            "SELECT * FROM admin WHERE username=? AND password=?" :
            "SELECT * FROM $tblname WHERE email=? AND password=?";

        $stmt = $this->probus->prepare($query);
        $stmt->bind_param("ss", $username, $password);
        $stmt->execute();
        $stmt->store_result();
        $count = $stmt->num_rows;
        $stmt->close();
        
        return $count;
    }

    // Insert data into a table
    public function insertData(array $fields, array $data, string $table): bool
    {
        $field_names = implode(",", $fields);
        $placeholders = rtrim(str_repeat("?,", count($fields)), ",");
        $sql = "INSERT INTO $table ($field_names) VALUES ($placeholders)";

        $stmt = $this->probus->prepare($sql);
        $stmt->bind_param(str_repeat("s", count($data)), ...$data);
        $result = $stmt->execute();
        $stmt->close();

        return $result;
    } 
    public function executeQuery($sql) {
        return $this->probus->query($sql)->fetch_row();
    }
    public function queryfire($sql){
        return $this->probus->query($sql);
    }
}
?>
